import React, { Component } from 'react';
import PropTypes from 'prop-types';
import shouldPureComponentUpdate from 'react-pure-render/function';
import { Tab } from './ActionPreview';
import { Base16Theme, StylingFunction, Theme } from 'react-base16-styling';
import { MonitorAction, MonitorState, reducer } from './redux';
import { LiftedAction, LiftedState } from 'redux-devtools';
import { Action, Dispatch } from 'redux';
import { Delta, DiffContext } from 'jsondiffpatch';
export interface Props<S, A extends Action<unknown>> extends LiftedState<S, A, MonitorState> {
    dispatch: Dispatch<MonitorAction | LiftedAction<S, A, MonitorState, MonitorAction>>;
    select: (state: S) => unknown;
    supportImmutable: boolean;
    draggableActions: boolean;
    tabs: Tab<S, A>[] | ((tabs: Tab<S, A>[]) => Tab<S, A>[]);
    theme: Theme;
    invertTheme: boolean;
    diffObjectHash?: (item: any, index: number) => string;
    diffPropertyFilter?: (name: string, context: DiffContext) => boolean;
    dataTypeKey?: string;
    hideMainButtons?: boolean;
    hideActionButtons?: boolean;
}
interface State<S, A extends Action<unknown>> {
    isWideLayout: boolean;
    themeState: {
        base16Theme: Base16Theme;
        styling: StylingFunction;
    };
    delta: Delta | null | undefined | false;
    nextState: S;
    action: A;
    error: string | undefined;
}
export default class DevtoolsInspector<S, A extends Action<unknown>> extends Component<Props<S, A>, State<S, A>> {
    constructor(props: Props<S, A>);
    static propTypes: {
        dispatch: PropTypes.Requireable<(...args: any[]) => any>;
        computedStates: PropTypes.Requireable<any[]>;
        stagedActionIds: PropTypes.Requireable<any[]>;
        actionsById: PropTypes.Requireable<object>;
        currentStateIndex: PropTypes.Requireable<number>;
        monitorState: PropTypes.Requireable<PropTypes.InferProps<{
            initialScrollTop: PropTypes.Requireable<number>;
        }>>;
        preserveScrollTop: PropTypes.Requireable<boolean>;
        draggableActions: PropTypes.Requireable<boolean>;
        stagedActions: PropTypes.Requireable<any[]>;
        select: PropTypes.Validator<(...args: any[]) => any>;
        theme: PropTypes.Requireable<string | object>;
        supportImmutable: PropTypes.Requireable<boolean>;
        diffObjectHash: PropTypes.Requireable<(...args: any[]) => any>;
        diffPropertyFilter: PropTypes.Requireable<(...args: any[]) => any>;
        hideMainButtons: PropTypes.Requireable<boolean>;
        hideActionButtons: PropTypes.Requireable<boolean>;
        invertTheme: PropTypes.Requireable<boolean>;
        skippedActionIds: PropTypes.Requireable<any[]>;
        dataTypeKey: PropTypes.Requireable<any>;
        tabs: PropTypes.Requireable<any[] | ((...args: any[]) => any)>;
    };
    static update: typeof reducer;
    static defaultProps: {
        select: (state: unknown) => unknown;
        supportImmutable: boolean;
        draggableActions: boolean;
        theme: string;
        invertTheme: boolean;
    };
    shouldComponentUpdate: typeof shouldPureComponentUpdate;
    updateSizeTimeout?: number;
    inspectorRef?: HTMLDivElement | null;
    componentDidMount(): void;
    componentWillUnmount(): void;
    updateMonitorState: (monitorState: Partial<MonitorState>) => void;
    updateSizeMode(): void;
    componentWillReceiveProps(nextProps: Props<S, A>): void;
    inspectorCreateRef: React.RefCallback<HTMLDivElement>;
    render(): JSX.Element;
    handleToggleAction: (actionId: number) => void;
    handleJumpToState: (actionId: number) => void;
    handleReorderAction: (actionId: number, beforeActionId: number) => void;
    handleCommit: () => void;
    handleSweep: () => void;
    handleSearch: (val: string) => void;
    handleSelectAction: (e: React.MouseEvent<HTMLDivElement, MouseEvent>, actionId: number) => void;
    handleInspectPath: (pathType: "inspectedStatePath" | "inspectedActionPath", path: (string | number)[]) => void;
    handleSelectTab: (tabName: string) => void;
}
export {};
